import {WebSocketPayload} from "../WebSocketPayload";
import {IDrink} from "../database/IDrink";
import {Pane} from "./Pane";
import {IContainer} from "../database/IContainer";
import {Setup} from "./Setup";
import {SensorType} from "../SensorType";

export class WebHandler {
    static get currentPane(): Pane {
        return this._currentPane;
    }
    private static containers = [];

    public static onDrinkUpdate(payload: WebSocketPayload) {
        if (!payload.data) return;
        let drinks: IDrink[] = payload.data;

        const main = document.getElementById("main");
        if (!main) return;

        main.style.gridTemplateRows = `repeat(${Math.round(drinks.length / 3)}, calc(90%/2))`;

        main.innerHTML = "";

        for (let drink of drinks) {
            let drinkEle = document.createElement("div");
            drinkEle.classList.add("drink");


            let drinkImg = document.createElement("img");
            drinkImg.classList.add("thumbnail");
            drinkEle.append(drinkImg);

            let drinkName = document.createElement("p");
            drinkName.classList.add("drinkName");
            drinkEle.append(drinkName);

            drinkImg.alt = "Foto von " + drink.name;
            drinkImg.src = "/images/" + drink.name + ".png";
            drinkName.innerText = drink.name;

            /*
            let ingredients = "<ul style='list-style-type: disc;'>";
            for (let i of drink.ingredients) {
                ingredients += "<li>" + i.amount + "ml " + i.type.name + "</li>";
            }
            ingredients += "</ul>"

            drinkEle.onclick = () => {
                let modal = new Modal("drink", drink.name);

                modal.content = `<strong>Zutaten</strong><br>
${ingredients}`*/ //todo
            //modal.leftCentered = true;
            // modal.open();
            //};

            //main.append(drinkEle);
        }

    }


    public static onContainerUpdate(payload: WebSocketPayload) {
        let containerDiv = document.getElementById("setupContainers") as HTMLDivElement;
        containerDiv.innerHTML = "";

        let containers = payload.data as IContainer[];
        for (let c of containers) {
            Setup.addSetupContainer();
        }

        let i = 0;
        let list = containerDiv.getElementsByTagName("div");
        for (let c of containers) {
            let current = list[i] as HTMLDivElement;
            let selects = current.getElementsByTagName("select");

            (selects[0] as HTMLSelectElement).value = c.pumpPin.toString();
            let type;
            if (c.sensorType == SensorType.NONE)
                type = "-1";
            else if (c.sensorType == SensorType.ULTRASOUND)
                type = "0";
            else
                type = "1";
            (selects[1] as HTMLSelectElement).value = type;
            (selects[2] as HTMLSelectElement).value = c.sensorPin1.toString();
            (selects[3] as HTMLSelectElement).value = c.sensorPin2.toString();
            (selects[4] as HTMLSelectElement).value = c.volume.toString();
            let event = new Event('change', {bubbles: true});
            selects[1].dispatchEvent(event);

            i++;
        }

    }

    private static _currentPane: Pane;

    public static openPane(pane: Pane): void {
        let mainPanel = document.getElementById("main") as HTMLDivElement;
        let setupPanel = document.getElementById("setup") as HTMLDivElement;
        let menuPanel = document.getElementById("menu") as HTMLDivElement;
        let settingsPanel = document.getElementById("settings") as HTMLDivElement;
        console.log("Opening pane " + pane);

        if (!this._currentPane) {
            mainPanel.classList.add("hiddenPane");
            setupPanel.classList.add("hiddenPane");
            menuPanel.classList.add("hiddenPane");
            settingsPanel.classList.add("hiddenPane");
        }

        switch (this._currentPane) {
            case Pane.MAIN: {
                mainPanel.classList.add("hiddenPane");
                break;
            }
            case Pane.MENU: {
                menuPanel.classList.add("hiddenPane");
                break;
            }
            case Pane.SETUP: {
                setupPanel.classList.add("hiddenPane");
                break;
            }
            case Pane.SETTINGS: {
                settingsPanel.classList.add("hiddenPane");
                break;
            }
        }


        let title = document.getElementById("title") as HTMLTitleElement;
        switch (pane) {
            case Pane.MAIN: {
                mainPanel.classList.remove("hiddenPane");
                title.innerText = "iTender";
                break;
            }
            case Pane.MENU: {
                menuPanel.classList.remove("hiddenPane");
                title.innerText = "Menü";
                break;
            }
            case Pane.SETUP: {
                setupPanel.classList.remove("hiddenPane");
                title.innerText = "Setup";
                break;
            }
            case Pane.SETTINGS: {
                settingsPanel.classList.remove("hiddenPane");
                title.innerText = "Einstellungen";
                break;
            }
        }

        this._currentPane = pane;
    }
}